==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/AllowedPrincipalsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory allowed principals.
 * @property groups The list of the allowed groups.
 * @property identities The list of the allowed identities.
 */
public data class AllowedPrincipalsArgs(
    public val groups: Output<List<String>>? = null,
    public val identities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs =
        com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs.builder()
            .groups(groups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .identities(identities?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AllowedPrincipalsArgs].
 */
@PulumiTagMarker
public class AllowedPrincipalsArgsBuilder internal constructor() {
    private var groups: Output<List<String>>? = null

    private var identities: Output<List<String>>? = null

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("abrmpfgrxxweecfk")
    public suspend fun groups(`value`: Output<List<String>>) {
        this.groups = value
    }

    @JvmName("ldjnguyabecwqmup")
    public suspend fun groups(vararg values: Output<String>) {
        this.groups = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("illrvykwtomhbuhm")
    public suspend fun groups(values: List<Output<String>>) {
        this.groups = Output.all(values)
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("mvjvtswrekihjluu")
    public suspend fun identities(`value`: Output<List<String>>) {
        this.identities = value
    }

    @JvmName("idgxjnqcbpfmpkmw")
    public suspend fun identities(vararg values: Output<String>) {
        this.identities = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("gvhlcvweiirrxdqd")
    public suspend fun identities(values: List<Output<String>>) {
        this.identities = Output.all(values)
    }

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("dclkemmkhfiqgpqg")
    public suspend fun groups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("xdjmcssvyfoxsxvo")
    public suspend fun groups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("djxtnlcdtlyannpa")
    public suspend fun identities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("ajcvtwsujaqqgjre")
    public suspend fun identities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    internal fun build(): AllowedPrincipalsArgs = AllowedPrincipalsArgs(
        groups = groups,
        identities = identities,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/AllowedPrincipalsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory allowed principals.
 * @property groups The list of the allowed groups.
 * @property identities The list of the allowed identities.
 */
public data class AllowedPrincipalsArgs(
    public val groups: Output<List<String>>? = null,
    public val identities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs =
        com.pulumi.azurenative.app.inputs.AllowedPrincipalsArgs.builder()
            .groups(groups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .identities(identities?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AllowedPrincipalsArgs].
 */
@PulumiTagMarker
public class AllowedPrincipalsArgsBuilder internal constructor() {
    private var groups: Output<List<String>>? = null

    private var identities: Output<List<String>>? = null

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("fvvibcdkipkigipn")
    public suspend fun groups(`value`: Output<List<String>>) {
        this.groups = value
    }

    @JvmName("fijiioruwgmfaodb")
    public suspend fun groups(vararg values: Output<String>) {
        this.groups = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("etqpivchyeddqyaf")
    public suspend fun groups(values: List<Output<String>>) {
        this.groups = Output.all(values)
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("qmrnlscbluleukul")
    public suspend fun identities(`value`: Output<List<String>>) {
        this.identities = value
    }

    @JvmName("tidcslejfrkvsvdk")
    public suspend fun identities(vararg values: Output<String>) {
        this.identities = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("fgghavkkrrjcrqkt")
    public suspend fun identities(values: List<Output<String>>) {
        this.identities = Output.all(values)
    }

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("bqinlykukoccdddl")
    public suspend fun groups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("pybyjumxgnrxwqgw")
    public suspend fun groups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("irseeuweowogkgmb")
    public suspend fun identities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("iufinmvmcvxagvga")
    public suspend fun identities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    internal fun build(): AllowedPrincipalsArgs = AllowedPrincipalsArgs(
        groups = groups,
        identities = identities,
    )
}
